<?php

namespace Drupal\text_style_manager\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 *
 */
class TextStyleSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['text_style_manager.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'text_style_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('text_style_manager.settings');

    $form['header_font'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Header Font Family'),
      '#default_value' => $config->get('header_font') ?? 'Arial',
    ];

    $form['body_font'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Body Font Family'),
      '#default_value' => $config->get('body_font') ?? 'Georgia',
    ];

    $form['footer_font'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Footer Font Family'),
      '#default_value' => $config->get('footer_font') ?? 'Verdana',
    ];

    $form['header_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Header Text Color'),
      '#default_value' => $config->get('header_color') ?? '#333333',
    ];

    $form['body_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Body Text Color'),
      '#default_value' => $config->get('body_color') ?? '#000000',
    ];

    $form['footer_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Footer Text Color'),
      '#default_value' => $config->get('footer_color') ?? '#666666',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('text_style_manager.settings')
      ->set('header_font', $form_state->getValue('header_font'))
      ->set('body_font', $form_state->getValue('body_font'))
      ->set('footer_font', $form_state->getValue('footer_font'))
      ->set('header_color', $form_state->getValue('header_color'))
      ->set('body_color', $form_state->getValue('body_color'))
      ->set('footer_color', $form_state->getValue('footer_color'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
